# KEGGX

Python package for manipulation and visualization of KEGG pathways.

See [notebooks/example.ipynb](https://github.com/iamjli/KEGGX/blob/master/notebooks/example.ipynb).

# Install

`pip install KEGGX`